@@ -6,6 +6,7 @@ use warnings;
 use Error::Pure qw(err);
 use List::Util 1.33 qw(none);
 use Mo qw(build is);
+use Mo::utils::CSS qw(check_css_class);
 use Readonly;
 
 Readonly::Array our @METHODS => qw(get post);
@@ -15,7 +16,7 @@ Readonly::Array our @ENCTYPES => (
 	'text/plain',
 );
 
-our $VERSION = 0.01;
+our $VERSION = 0.09;
 
 has action => (
 	is => 'ro',
@@ -44,6 +45,9 @@ has method => (
 sub BUILD {
 	my $self = shift;
 
+	# Check CSS class.
+	check_css_class($self, 'css_class');
+
 	# Check enctype.
 	if (defined $self->{'enctype'}) {
 		if (none { $self->{'enctype'} eq $_ } @ENCTYPES) {
@@ -269,6 +273,7 @@ Returns string.
 L<Error::Pure>,
 L<List::Util>,
 L<Mo>,
+L<Mo::utils::CSS>,
 L<Readonly>.
 
 =head1 REPOSITORY
@@ -289,6 +294,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.01
+0.09
 
 =cut
