@@ -5,8 +5,9 @@ use warnings;
 
 use Mo qw(build is);
 use Mo::utils qw(check_bool check_number);
+use Mo::utils::CSS qw(check_css_class);
 
-our $VERSION = 0.03;
+our $VERSION = 0.09;
 
 has autofocus => (
 	is => 'ro',
@@ -69,6 +70,9 @@ sub BUILD {
 	}
 	check_bool($self, 'autofocus');
 
+	# Check css_class.
+	check_css_class($self, 'css_class');
+
 	# Check cols.
 	check_number($self, 'cols');
 
@@ -379,7 +383,8 @@ Returns string.
 =head1 DEPENDENCIES
 
 L<Mo>,
-L<Mo::utils>.
+L<Mo::utils>,
+L<Mo::utils::CSS>.
 
 =head1 REPOSITORY
 
@@ -399,6 +404,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.03
+0.09
 
 =cut
